@@ -5,7 +5,6 @@ import random
 import argparse
 from Bio import SeqIO
 from Bio.Seq import Seq
-from Bio.Alphabet import generic_dna
 
 
 Reads_simulator_usage = '''
@@ -64,7 +63,7 @@ def Reads_simulator(args):
             current_fragment = seq_part_1_seq + seq_part_2_seq
         current_fragment_r1 = current_fragment[:read_length]
         current_fragment_r2 = current_fragment[-read_length:]
-        current_fragment_r2_reverse_complement = str(Seq(current_fragment_r2, generic_dna).reverse_complement())
+        current_fragment_r2_reverse_complement = str(Seq(current_fragment_r2).reverse_complement())
         current_read_r1_id = '%s_%s.1' % (genome_name, n)
         current_read_r2_id = '%s_%s.2' % (genome_name, n)
 
@@ -92,7 +91,7 @@ if __name__ == '__main__':
 
     parser = argparse.ArgumentParser()
 
-    parser.add_argument('-r',     required=True,           help='reference genomes')
+    parser.add_argument('-r',     required=True,           help='reference genome')
     parser.add_argument('-n',     required=True, type=int, help='reads number')
     parser.add_argument('-l',     required=True, type=int, help='reads length')
     parser.add_argument('-i',     required=True, type=int, help='insert size')
