@@ -11,10 +11,10 @@ download_GenBank_genome_parser_usage = '''
 ================================== dwnld_GenBank_genome example commands ==================================
 
 # Usage:
-# 1. Go to https://www.ncbi.nlm.nih.gov/genome/browse#!/prokaryotes/refseq_category:reference
-# 2. Search the taxonomy of genomes you want to download (e.g. prokaryotes, proteobacteria)
-# 3. Click "Download" on the right side
-# 4. provide the downloaded csv file to BioSAK with '-csv'
+1. Go to https://www.ncbi.nlm.nih.gov/genome/browse#!/prokaryotes/refseq_category:reference
+2. Search the taxonomy of genomes you want to download (e.g. prokaryotes, proteobacteria)
+3. Click "Download" on the right side
+4. provide the downloaded csv file to BioSAK with '-csv'
 
 # Example commands
 BioSAK dwnld_GenBank_genome -csv prokaryotes.csv -fna -name
